@@ -135,7 +135,7 @@ lsm_p_gyrate_calc <- function(landscape, directions,
                               points = NULL) {
 
     # conver to matrix
-    if(class(landscape) != "matrix") {
+    if (!inherits(x = landscape, what = "matrix")) {
 
         # get coordinates and values of all cells
         points <- raster_to_points(landscape)[, 2:4]
@@ -144,6 +144,15 @@ lsm_p_gyrate_calc <- function(landscape, directions,
         landscape <- raster::as.matrix(landscape)
     }
 
+    # all values NA
+    if (all(is.na(landscape))) {
+        return(tibble::tibble(level = "patch",
+                              class = as.integer(NA),
+                              id = as.integer(NA),
+                              metric = "gyrate",
+                              value = as.double(NA)))
+    }
+
     # get uniuqe class id
     classes <- get_unique_values(landscape)[[1]]
 
